==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIinc.h <==
// class soot.coffi.Instruction_Iinc

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 6e003e37731ab203 soot_coffi_Instruction__5fIinc
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fIinc_H_
#define _JC_soot_coffi_Instruction__5fIinc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIinc$sub_refs	_jc_soot_coffi_Instruction__5fIinc$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIinc$sub_nonrefs	_jc_soot_coffi_Instruction__5fIinc$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIinc$refs	_jc_soot_coffi_Instruction__5fIinc$refs;
typedef struct _jc_soot_coffi_Instruction__5fIinc$nonrefs	_jc_soot_coffi_Instruction__5fIinc$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIinc$object	_jc_soot_coffi_Instruction__5fIinc$object;

typedef const struct _jc_soot_coffi_Instruction__5fIinc$vmethods	_jc_soot_coffi_Instruction__5fIinc$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIinc$vtable	_jc_soot_coffi_Instruction__5fIinc$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIinc$vtype	_jc_soot_coffi_Instruction__5fIinc$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIinc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *);

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fIinc$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_byte_array *, jint);
extern jint _jc_soot_coffi_Instruction__5fIinc$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, jint);
extern jint _jc_soot_coffi_Instruction__5fIinc$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_byte_array *, jint);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fIinc$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fIinc$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fIinc$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fIinc$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fIinc$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIinc$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_byte_array *, jint);
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, jint);
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_byte_array *, jint);
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIinc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fIinc$vmethods	soot_coffi_Instruction__5fIinc;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIinc$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIinc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIinc$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIinc$refs {
    _jc_soot_coffi_Instruction__5fIinc$sub_refs	soot_coffi_Instruction__5fIinc;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIinc$sub_nonrefs {
	jint	arg__5fc;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIinc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fIinc$sub_nonrefs	soot_coffi_Instruction__5fIinc;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIinc$object {
	_jc_soot_coffi_Instruction__5fIinc$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIinc$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIinc$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIinc$vtype _jc_soot_coffi_Instruction__5fIinc$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIinc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIinc$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIinc_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIinc.h <==
// class soot.coffi.Instruction_Iinc

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 6e003e37731ab203 soot_coffi_Instruction__5fIinc
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fIinc_H_
#define _JC_soot_coffi_Instruction__5fIinc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIinc$sub_refs	_jc_soot_coffi_Instruction__5fIinc$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIinc$sub_nonrefs	_jc_soot_coffi_Instruction__5fIinc$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIinc$refs	_jc_soot_coffi_Instruction__5fIinc$refs;
typedef struct _jc_soot_coffi_Instruction__5fIinc$nonrefs	_jc_soot_coffi_Instruction__5fIinc$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIinc$object	_jc_soot_coffi_Instruction__5fIinc$object;

typedef const struct _jc_soot_coffi_Instruction__5fIinc$vmethods	_jc_soot_coffi_Instruction__5fIinc$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIinc$vtable	_jc_soot_coffi_Instruction__5fIinc$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIinc$vtype	_jc_soot_coffi_Instruction__5fIinc$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIinc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fIinc$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fIinc$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fIinc$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fIinc$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fIinc$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fIinc$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fIinc$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fIinc$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIinc$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, jint) _JC_JCNI_ATTR;
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fIinc$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIinc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fIinc$vmethods	soot_coffi_Instruction__5fIinc;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIinc$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIinc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIinc$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIinc$refs {
    _jc_soot_coffi_Instruction__5fIinc$sub_refs	soot_coffi_Instruction__5fIinc;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIinc$sub_nonrefs {
	jint	arg__5fc;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIinc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fIinc$sub_nonrefs	soot_coffi_Instruction__5fIinc;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIinc$object {
	_jc_soot_coffi_Instruction__5fIinc$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIinc$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIinc$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIinc$vtype _jc_soot_coffi_Instruction__5fIinc$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIinc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIinc$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIinc_H_ */
